@@ -11,6 +11,7 @@ import pytorch_lightning as pl
 from TSFEDL.data import MIT_BIH
 from torch.utils.data.sampler import SubsetRandomSampler
 from TSFEDL.models_pytorch import *
+import inspect
 
 
 def acc_from_logits(y_hat, y):
@@ -28,6 +29,8 @@ class MyTestCase(unittest.TestCase):
             os.system("wget -r -N -c -np https://physionet.org/files/mitdb/1.0.0/")
 
     def trainModel(self, model, data_length, epochs, hot_coded=False, evaluate_test=True):
+        if torch.cuda.is_available():
+            torch.cuda.empty_cache()    
         mit_bih = MIT_BIH(path="physionet.org/files/mitdb/1.0.0/", return_hot_coded=hot_coded)
         mit_bih.x = mit_bih.x[:10]
         mit_bih.y = mit_bih.y[:10]
@@ -41,11 +44,18 @@ class MyTestCase(unittest.TestCase):
 
 
         # Train
-        #trainer = pl.Trainer(gpus=1, max_epochs=epochs)
-        trainer = pl.Trainer(max_epochs=epochs)
-        trainer.fit(model=model, train_dataloader=train_loader)
+        trainer = None
+        if torch.cuda.is_available():
+            trainer = pl.Trainer(gpus=1, max_epochs=epochs)
+        else:
+            trainer = pl.Trainer(max_epochs=epochs)
+        trainer.fit(model, train_loader)
         if evaluate_test:
-            test_results = trainer.test(test_dataloaders=test_loader)
+            test_results = None
+            if "model" in inspect.getfullargspec(trainer.test).args:
+                test_results = trainer.test(model, test_loader)
+            else:
+                test_results = trainer.test(test_loader)
             return test_results[0]['test_acc_epoch']
 
     #@unittest.skip
